'Simple VB.NET example uses the LabJackUD driver to communicate with a U6.
Option Explicit On 

Imports System.Threading.Thread

' Import the UD .NET wrapper object.  The dll referenced is installed by the
' LabJackUD installer.
Imports LabJack.LabJackUD


Public Class Form1
    Inherits System.Windows.Forms.Form

    Sub ErrorMessage(ByVal err As LabJackUDException)
        MsgBox("Function returned LabJackUD Error #" & _
            Str$(err.LJUDError) & _
            "  " & _
            err.ToString)
    End Sub

    Public Sub New()
        MyBase.New()

        'This call is required by the Windows Form Designer.
        InitializeComponent()

        Dim lngError As Integer
        Dim lngHandle As Integer
        Dim dblDriverVersion As Double
        Dim strError(255) As Char
        Dim dblSerialNumber As Double
        Dim dblAIN2 As Double
        Dim dblAIN3 As Double
        Dim dblFIO1 As Double
        Dim dblPort As Double
        Dim dblCount0 As Double

        'Retrieve the LabJackUD driver version.
        dblDriverVersion = LJUD.GetDriverVersion()
        txtDriverVersion.Text = Str(dblDriverVersion)
        textDNDriverVersion.Text = LJUD.LJUDDOTNET_VERSION

        'Open the first found LabJack U6 over USB.
        Try

            LJUD.OpenLabJack(LJUD.DEVICE.U6, LJUD.CONNECTION.USB, "0", 1, lngHandle)
        Catch x As LabJackUDException
            ErrorMessage(x)
            lngError = x.LJUDError
        End Try

        txtHandle.Text = Str(lngHandle)
        txtOpenErrorNumber.Text = Str(lngError)
        'Convert the error code to a string.
        LJUD.ErrorToString(lngError, strError)
        txtOpenErrorString.Text = strError


        Try
            'First, examples using eGet():
            'Read and display the serial number.
            LJUD.eGet(lngHandle, LJUD.IO.GET_CONFIG, LJUD.CHANNEL.SERIAL_NUMBER, dblSerialNumber, 0)
            txtSerialNumber.Text = Str(dblSerialNumber)

            'First some configuration commands.  These will be done with the ePut
            'function which combines the add/go/get into a single call.

            'Configure the resolution of the analog inputs (pass a non-zero value for quick sampling). 
            'See section 2.6 / 3.1 for more information.
            LJUD.ePut(lngHandle, LJUD.IO.PUT_CONFIG, LJUD.CHANNEL.AIN_RESOLUTION, 0, 0)

            'Configure the analog input range on channels 2 and 3 for bipolar 10v.
            LJUD.ePut(lngHandle, LJUD.IO.PUT_AIN_RANGE, 2, LJUD.RANGES.BIP10V, 0)
            LJUD.ePut(lngHandle, LJUD.IO.PUT_AIN_RANGE, 3, LJUD.RANGES.BIP10V, 0)

            'Now, the example is using AddRequest/GoOne/GetResult.  This method can
            'have a speed advantage, as multiple requests can be handled in a single
            'low-level command:

            'Request a reading from AIN2 and AIN3.
            LJUD.AddRequest(lngHandle, LJUD.IO.GET_AIN, 2, 0, 0, 0)
            LJUD.AddRequest(lngHandle, LJUD.IO.GET_AIN, 3, 0, 0, 0)

            'Request to set DAC0 to 2.5 volts.
            LJUD.AddRequest(lngHandle, LJUD.IO.PUT_DAC, 0, 2.5, 0, 0)

            'Request the state of FIO1.
            LJUD.AddRequest(lngHandle, LJUD.IO.GET_DIGITAL_BIT, 1, 0, 0, 0)

            ' Set digital output FIO2 to output-high.
            LJUD.AddRequest(lngHandle, LJUD.IO.PUT_DIGITAL_BIT, 2, 1, 0, 0)

            ' Read digital inputs FIO3 through FIO7.
            LJUD.AddRequest(lngHandle, LJUD.IO.GET_DIGITAL_PORT, 3, 0, 5, 0)

            'Execute the requests on a single LabJack.  The driver will use a
            'single low-level Feedback command to handle all the requests above.
            LJUD.GoOne(lngHandle)

            'Get the analog input voltage readings.
            LJUD.GetResult(lngHandle, LJUD.IO.GET_AIN, 2, dblAIN2)
            LJUD.GetResult(lngHandle, LJUD.IO.GET_AIN, 3, dblAIN3)

            'Get the DAC request result just to check for an errorcode.
            LJUD.GetResult(lngHandle, LJUD.IO.PUT_DAC, 0, 0)

            'Get the state of FIO1.
            LJUD.GetResult(lngHandle, LJUD.IO.GET_DIGITAL_BIT, 1, dblFIO1)

            'Get the digital output FIO2 result to check for an errorcode.
            LJUD.GetResult(lngHandle, LJUD.IO.PUT_DIGITAL_BIT, 2, 0)

            'Get the digital inputs FIO3 through FIO7.
            LJUD.GetResult(lngHandle, LJUD.IO.GET_DIGITAL_PORT, 3, dblPort)

            txtAIN.Text = Format(dblAIN2, "#.#####") + ", " + Format(dblAIN3, "#.#####")
            txtFIO1.Text = Str(dblFIO1)
            txtPort.Text = Str(dblPort)

            'Offset the timer/counters by 0 so they start appearing on FIO0.
            LJUD.AddRequest(lngHandle, LJUD.IO.PUT_CONFIG, LJUD.CHANNEL.TIMER_COUNTER_PIN_OFFSET, 0, 0, 0)

            'Enable Counter0.  It will use FIO0.
            LJUD.AddRequest(lngHandle, LJUD.IO.PUT_COUNTER_ENABLE, 0, 1, 0, 0)

            'Execute the requests on a single LabJack.  The driver will use a
            'single low-level TimerCounter command to handle all the requests above.
            LJUD.GoOne(lngHandle)

            'Now we will do all the GetResults just to check for errors.
            LJUD.GetResult(lngHandle, LJUD.IO.PUT_CONFIG, LJUD.CHANNEL.TIMER_COUNTER_PIN_OFFSET, 0)
            LJUD.GetResult(lngHandle, LJUD.IO.PUT_COUNTER_ENABLE, 0, 0)

            'Wait for 500 ms.
            Sleep(500)

            'Get the value of Counter0.
            LJUD.eGet(lngHandle, LJUD.IO.GET_COUNTER, 0, dblCount0, 0)
            txtCount0.Text = Str(dblCount0)

            'Disable the counter.
            LJUD.AddRequest(lngHandle, LJUD.IO.PUT_COUNTER_ENABLE, 0, 0, 0, 0)
            LJUD.GoOne(lngHandle)
        Catch x As LabJackUDException
            ErrorMessage(x)
        End Try

    End Sub

    'Form overrides dispose to clean up the component list.
    Protected Overloads Overrides Sub Dispose(ByVal disposing As Boolean)
        If disposing Then
            If Not (components Is Nothing) Then
                components.Dispose()
            End If
        End If
        MyBase.Dispose(disposing)
    End Sub

    'Required by the Windows Form Designer
    Private components As System.ComponentModel.IContainer

    'NOTE: The following procedure is required by the Windows Form Designer
    'It can be modified using the Windows Form Designer.  
    'Do not modify it using the code editor.
    Friend WithEvents txtSerialNumber As System.Windows.Forms.TextBox
    Friend WithEvents Label10 As System.Windows.Forms.Label
    Friend WithEvents Label9 As System.Windows.Forms.Label
    Friend WithEvents textDNDriverVersion As System.Windows.Forms.TextBox
    Friend WithEvents btnClose As System.Windows.Forms.Button
    Friend WithEvents txtAIN As System.Windows.Forms.TextBox
    Friend WithEvents txtOpenErrorString As System.Windows.Forms.TextBox
    Friend WithEvents txtOpenErrorNumber As System.Windows.Forms.TextBox
    Friend WithEvents txtHandle As System.Windows.Forms.TextBox
    Friend WithEvents txtDriverVersion As System.Windows.Forms.TextBox
    Friend WithEvents Label7 As System.Windows.Forms.Label
    Friend WithEvents Label6 As System.Windows.Forms.Label
    Friend WithEvents Label5 As System.Windows.Forms.Label
    Friend WithEvents Label4 As System.Windows.Forms.Label
    Friend WithEvents Label3 As System.Windows.Forms.Label
    Friend WithEvents Label2 As System.Windows.Forms.Label
    Friend WithEvents Label1 As System.Windows.Forms.Label
    Friend WithEvents txtCount0 As System.Windows.Forms.TextBox
    Friend WithEvents txtFIO6 As System.Windows.Forms.TextBox
    Friend WithEvents txtPort As System.Windows.Forms.TextBox
    Friend WithEvents Label8 As System.Windows.Forms.Label
    Friend WithEvents txtFIO1 As System.Windows.Forms.TextBox
    <System.Diagnostics.DebuggerStepThrough()> Private Sub InitializeComponent()
        Me.txtSerialNumber = New System.Windows.Forms.TextBox
        Me.Label10 = New System.Windows.Forms.Label
        Me.Label9 = New System.Windows.Forms.Label
        Me.textDNDriverVersion = New System.Windows.Forms.TextBox
        Me.btnClose = New System.Windows.Forms.Button
        Me.txtCount0 = New System.Windows.Forms.TextBox
        Me.txtFIO1 = New System.Windows.Forms.TextBox
        Me.txtAIN = New System.Windows.Forms.TextBox
        Me.txtOpenErrorString = New System.Windows.Forms.TextBox
        Me.txtOpenErrorNumber = New System.Windows.Forms.TextBox
        Me.txtHandle = New System.Windows.Forms.TextBox
        Me.txtDriverVersion = New System.Windows.Forms.TextBox
        Me.Label7 = New System.Windows.Forms.Label
        Me.Label6 = New System.Windows.Forms.Label
        Me.Label5 = New System.Windows.Forms.Label
        Me.Label4 = New System.Windows.Forms.Label
        Me.Label3 = New System.Windows.Forms.Label
        Me.Label2 = New System.Windows.Forms.Label
        Me.Label1 = New System.Windows.Forms.Label
        Me.txtPort = New System.Windows.Forms.TextBox
        Me.Label8 = New System.Windows.Forms.Label
        Me.SuspendLayout()
        '
        'txtSerialNumber
        '
        Me.txtSerialNumber.Location = New System.Drawing.Point(12, 145)
        Me.txtSerialNumber.Name = "txtSerialNumber"
        Me.txtSerialNumber.Size = New System.Drawing.Size(162, 20)
        Me.txtSerialNumber.TabIndex = 42
        '
        'Label10
        '
        Me.Label10.Location = New System.Drawing.Point(12, 129)
        Me.Label10.Name = "Label10"
        Me.Label10.Size = New System.Drawing.Size(112, 13)
        Me.Label10.TabIndex = 41
        Me.Label10.Text = "Serial Number"
        '
        'Label9
        '
        Me.Label9.Location = New System.Drawing.Point(195, 16)
        Me.Label9.Name = "Label9"
        Me.Label9.Size = New System.Drawing.Size(128, 16)
        Me.Label9.TabIndex = 40
        Me.Label9.Text = "LJUDDotNet Version"
        '
        'textDNDriverVersion
        '
        Me.textDNDriverVersion.Location = New System.Drawing.Point(195, 32)
        Me.textDNDriverVersion.Name = "textDNDriverVersion"
        Me.textDNDriverVersion.Size = New System.Drawing.Size(162, 20)
        Me.textDNDriverVersion.TabIndex = 39
        '
        'btnClose
        '
        Me.btnClose.Location = New System.Drawing.Point(282, 261)
        Me.btnClose.Name = "btnClose"
        Me.btnClose.Size = New System.Drawing.Size(75, 23)
        Me.btnClose.TabIndex = 23
        Me.btnClose.Text = "Close"
        '
        'txtCount0
        '
        Me.txtCount0.Location = New System.Drawing.Point(12, 304)
        Me.txtCount0.Name = "txtCount0"
        Me.txtCount0.Size = New System.Drawing.Size(162, 20)
        Me.txtCount0.TabIndex = 37
        '
        'txtFIO1
        '
        Me.txtFIO1.Location = New System.Drawing.Point(12, 225)
        Me.txtFIO1.Name = "txtFIO1"
        Me.txtFIO1.Size = New System.Drawing.Size(162, 20)
        Me.txtFIO1.TabIndex = 43
        '
        'txtAIN
        '
        Me.txtAIN.Location = New System.Drawing.Point(12, 185)
        Me.txtAIN.Name = "txtAIN"
        Me.txtAIN.Size = New System.Drawing.Size(162, 20)
        Me.txtAIN.TabIndex = 35
        '
        'txtOpenErrorString
        '
        Me.txtOpenErrorString.Location = New System.Drawing.Point(193, 145)
        Me.txtOpenErrorString.Multiline = True
        Me.txtOpenErrorString.Name = "txtOpenErrorString"
        Me.txtOpenErrorString.Size = New System.Drawing.Size(264, 60)
        Me.txtOpenErrorString.TabIndex = 34
        '
        'txtOpenErrorNumber
        '
        Me.txtOpenErrorNumber.Location = New System.Drawing.Point(195, 104)
        Me.txtOpenErrorNumber.Name = "txtOpenErrorNumber"
        Me.txtOpenErrorNumber.Size = New System.Drawing.Size(162, 20)
        Me.txtOpenErrorNumber.TabIndex = 33
        '
        'txtHandle
        '
        Me.txtHandle.Location = New System.Drawing.Point(12, 104)
        Me.txtHandle.Name = "txtHandle"
        Me.txtHandle.Size = New System.Drawing.Size(162, 20)
        Me.txtHandle.TabIndex = 32
        '
        'txtDriverVersion
        '
        Me.txtDriverVersion.Location = New System.Drawing.Point(12, 32)
        Me.txtDriverVersion.Name = "txtDriverVersion"
        Me.txtDriverVersion.Size = New System.Drawing.Size(162, 20)
        Me.txtDriverVersion.TabIndex = 31
        '
        'Label7
        '
        Me.Label7.Location = New System.Drawing.Point(12, 288)
        Me.Label7.Name = "Label7"
        Me.Label7.Size = New System.Drawing.Size(112, 16)
        Me.Label7.TabIndex = 30
        Me.Label7.Text = "Count0"
        '
        'Label6
        '
        Me.Label6.Location = New System.Drawing.Point(12, 209)
        Me.Label6.Name = "Label6"
        Me.Label6.Size = New System.Drawing.Size(112, 16)
        Me.Label6.TabIndex = 29
        Me.Label6.Text = "FIO1"
        '
        'Label5
        '
        Me.Label5.Location = New System.Drawing.Point(12, 169)
        Me.Label5.Name = "Label5"
        Me.Label5.Size = New System.Drawing.Size(112, 13)
        Me.Label5.TabIndex = 28
        Me.Label5.Text = "AIN2, AIN3"
        '
        'Label4
        '
        Me.Label4.Location = New System.Drawing.Point(193, 129)
        Me.Label4.Name = "Label4"
        Me.Label4.Size = New System.Drawing.Size(100, 16)
        Me.Label4.TabIndex = 27
        Me.Label4.Text = "Open Error String"
        '
        'Label3
        '
        Me.Label3.Location = New System.Drawing.Point(195, 88)
        Me.Label3.Name = "Label3"
        Me.Label3.Size = New System.Drawing.Size(112, 16)
        Me.Label3.TabIndex = 26
        Me.Label3.Text = "Open Error Number"
        '
        'Label2
        '
        Me.Label2.Location = New System.Drawing.Point(12, 88)
        Me.Label2.Name = "Label2"
        Me.Label2.Size = New System.Drawing.Size(112, 16)
        Me.Label2.TabIndex = 25
        Me.Label2.Text = "Handle"
        '
        'Label1
        '
        Me.Label1.Location = New System.Drawing.Point(12, 16)
        Me.Label1.Name = "Label1"
        Me.Label1.Size = New System.Drawing.Size(96, 16)
        Me.Label1.TabIndex = 24
        Me.Label1.Text = "UD Driver Version"
        '
        'txtPort
        '
        Me.txtPort.Location = New System.Drawing.Point(12, 264)
        Me.txtPort.Name = "txtPort"
        Me.txtPort.Size = New System.Drawing.Size(162, 20)
        Me.txtPort.TabIndex = 45
        '
        'Label8
        '
        Me.Label8.Location = New System.Drawing.Point(12, 248)
        Me.Label8.Name = "Label8"
        Me.Label8.Size = New System.Drawing.Size(121, 16)
        Me.Label8.TabIndex = 44
        Me.Label8.Text = "FIO3-FIO7"
        '
        'Form1
        '
        Me.AutoScaleBaseSize = New System.Drawing.Size(5, 13)
        Me.ClientSize = New System.Drawing.Size(469, 357)
        Me.Controls.Add(Me.txtPort)
        Me.Controls.Add(Me.Label8)
        Me.Controls.Add(Me.txtSerialNumber)
        Me.Controls.Add(Me.Label10)
        Me.Controls.Add(Me.Label9)
        Me.Controls.Add(Me.textDNDriverVersion)
        Me.Controls.Add(Me.btnClose)
        Me.Controls.Add(Me.txtCount0)
        Me.Controls.Add(Me.txtFIO1)
        Me.Controls.Add(Me.txtAIN)
        Me.Controls.Add(Me.txtOpenErrorString)
        Me.Controls.Add(Me.txtOpenErrorNumber)
        Me.Controls.Add(Me.txtHandle)
        Me.Controls.Add(Me.txtDriverVersion)
        Me.Controls.Add(Me.Label7)
        Me.Controls.Add(Me.Label6)
        Me.Controls.Add(Me.Label5)
        Me.Controls.Add(Me.Label4)
        Me.Controls.Add(Me.Label3)
        Me.Controls.Add(Me.Label2)
        Me.Controls.Add(Me.Label1)
        Me.Name = "Form1"
        Me.Text = "Simple U6 VB.NET Example"
        Me.ResumeLayout(False)
        Me.PerformLayout()

    End Sub

    Private Sub btnClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnClose.Click
        Me.Close()
    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

    End Sub
End Class
